==> cdc-issues-api-0.8.0-sources.jar: cdc/issues/FormalParams.java <==
package cdc.issues;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * Formal parameters.
 *
 * @author Damien Carbonne
 */
public class FormalParams {
    public static final FormalParams NO_PARAMS = builder().build();

    private final Map<String, String> map = new HashMap<>();

    private FormalParams(Map<String, String> map) {
        for (final Map.Entry<String, String> entry : map.entrySet()) {
            this.map.put(entry.getKey(), entry.getValue());
        }
    }

    public boolean isEmpty() {
        return map.isEmpty();
    }

    /**
     * @return The parameter names.
     */
    public Set<String> getNames() {
        return map.keySet();
    }

    /**
     * @return The sorted parameter names.
     */
    public List<String> getSortedNames() {
        return map.keySet()
                  .stream()
                  .sorted()
                  .collect(Collectors.toList());
    }

    /**
     * @param name The parameter name.
     * @return The description of parameter named {@code name}.
     */
    public String getDescription(String name) {
        return map.get(name);
    }

    @Override
    public int hashCode() {
        return map.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        if (this == object) {
            return true;
        }
        if (!(object instanceof FormalParams)) {
            return false;
        }
        final FormalParams other = (FormalParams) object;
        return this.map.equals(other.map);
    }

    @Override
    public String toString() {
        return getSortedNames().stream()
                               .map(name -> name + ":" + getDescription(name))
                               .collect(Collectors.joining(" ", "[", "]"));
    }

    public static Builder builder() {
        return new Builder();
    }

    public static class Builder {
        private final Map<String, String> map = new HashMap<>();

        private Builder() {
        }

        public Builder param(String name,
                             String description) {
            map.put(name, description);
            return this;
        }

        public FormalParams build() {
            return new FormalParams(map);
        }
    }
}

==> cdc-issues-api-0.22.0-sources.jar: cdc/issues/FormalParams.java <==
package cdc.issues;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * Formal parameters.
 *
 * @author Damien Carbonne
 */
public final class FormalParams {
    public static final FormalParams NO_PARAMS = builder().build();

    private final Map<String, String> map = new HashMap<>();

    private FormalParams(Map<String, String> map) {
        for (final Map.Entry<String, String> entry : map.entrySet()) {
            this.map.put(entry.getKey(), entry.getValue());
        }
    }

    public boolean isEmpty() {
        return map.isEmpty();
    }

    /**
     * @return The parameter names.
     */
    public Set<String> getNames() {
        return map.keySet();
    }

    /**
     * @return The sorted parameter names.
     */
    public List<String> getSortedNames() {
        return map.keySet()
                  .stream()
                  .sorted()
                  .collect(Collectors.toList());
    }

    /**
     * @param name The parameter name.
     * @return The description of parameter named {@code name}.
     */
    public String getDescription(String name) {
        return map.get(name);
    }

    @Override
    public int hashCode() {
        return map.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        if (this == object) {
            return true;
        }
        if (!(object instanceof FormalParams)) {
            return false;
        }
        final FormalParams other = (FormalParams) object;
        return this.map.equals(other.map);
    }

    @Override
    public String toString() {
        return getSortedNames().stream()
                               .map(name -> name + ":" + getDescription(name))
                               .collect(Collectors.joining(" ", "[", "]"));
    }

    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private final Map<String, String> map = new HashMap<>();

        private Builder() {
        }

        public Builder param(String name,
                             String description) {
            map.put(name, description);
            return this;
        }

        public FormalParams build() {
            return new FormalParams(map);
        }
    }
}
